package com.diagbot.facade.data;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.diagbot.dto.AnalyzeRunDTO;
import com.diagbot.dto.RecordContentDTO;
import com.diagbot.dto.RespDTO;
import com.diagbot.dto.data.AMedicalRecordDTO;
import com.diagbot.dto.data.AMrContentDTO;
import com.diagbot.entity.*;
import com.diagbot.enums.ModeIdEnum;
import com.diagbot.enums.data.*;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.facade.*;
import com.diagbot.service.BehospitalInfoService;
import com.diagbot.service.ModelHospitalService;
import com.diagbot.service.impl.MedicalRecordServiceImpl;
import com.diagbot.service.impl.QcAbnormalServiceImpl;
import com.diagbot.util.*;
import com.diagbot.vo.AnalyzeRunVO;
import com.diagbot.vo.MedrecVo;
import com.diagbot.vo.QueryVo;
import com.diagbot.vo.data.*;
import com.google.common.collect.Lists;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

@Component
@Slf4j
public class AMedicalRecordFacade extends MedicalRecordServiceImpl {

    @Autowired
    @Qualifier("medicalRecordServiceImpl")
    private MedicalRecordServiceImpl medicalRecordService;

    @Autowired
    private ModelHospitalFacade modelHospitalFacade;

    @Autowired
    @Qualifier("modelHospitalServiceImpl")
    private ModelHospitalService modelHospitalService;

    @Autowired
    private BehospitalInfoFacade behospitalInfoService;

    @Autowired
    private AMedicalRecordContentFacade aMedicalRecordContentFacade;

    @Autowired
    private BehospitalInfoFacade behospitalInfoFacade;

    @Autowired
    @Qualifier("qcAbnormalServiceImpl")
    private QcAbnormalServiceImpl qcAbnormalService;

    @Autowired
    private QcTypeFacade qcTypeFacade;

    @Autowired
    private ReadProperties readProperties;

    @Autowired
    private BasHospitalInfoFacade basHospitalInfoFacade;

    @Autowired
    private AMedAbnormalInfoFacade aMedAbnormalInfoFacade;

    private TZDBConn tzDBConn = new TZDBConn();

    @Autowired
    private ColumnFacade columnFacade;

    @Autowired
    private AHomePageFacade aHomePageFacade;

    public static final Map<String, String> CITY_MAP = MapUtil.getMap("cityCode.json");

    @Value("${encrypt.enable}")
    Boolean encryptFlag;

    @Value("${xml_analyse.enable}")
    Boolean xmlAnalyseFlag;

    @Value("${log_switch.enable}")
    private boolean logSwitch;

    /**
     * 终末质控-同步前一天的病历记录
     */
    public void executeMrRecord() {
        String sql = "select * from ai_v_sendmrrecording where behospitalcode in()";
        List<MedicalRecord> medicalRecordList = tzDBConn.getMedicalRecord(sql);
        execute(medicalRecordList);
    }

    /**
     * 终末质控-通过接口更新病历记录
     *
     * @param list
     * @return
     */
    @Transactional
    public RespDTO<List<AMedicalRecordDTO>> executeMrRecord(List<AMedicalRecordVO> list) {
        try {
            if (list != null && list.size() > 0) {
                //循环验证数据有效性
                for (AMedicalRecordVO aMedicalRecordVO : list) {
                    if ("".equals(aMedicalRecordVO.getRecId())) {
                        return RespDTO.onError("请输入文书序号!");
                    } else if (aMedicalRecordVO.getHospitalId() == null) {
                        return RespDTO.onError("请输入医院编码!");
                    } else if ("".equals(aMedicalRecordVO.getBehospitalCode())) {
                        return RespDTO.onError("请输入病人住院编码!");
                    }
                }
                //装载数据
                List<MedicalRecord> medicalRecordList = Lists.newArrayList();
                list.stream().forEach(s -> {
                    MedicalRecord medicalRecord = new MedicalRecord();
                    BeanUtil.copyProperties(s, medicalRecord);
                    medicalRecord.setRecDate(DateUtil.parseDateTime(s.getRecDate()));
                    medicalRecordList.add(medicalRecord);
                });
                execute(medicalRecordList);
                List<AMedicalRecordDTO> medicalRecordDTOList = BeanUtil.listCopyTo(list, AMedicalRecordDTO.class);
                return RespDTO.onSuc(medicalRecordDTOList);
            } else {
                aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息", "", JSON.toJSONString(list), "", "未接收到数据!");
                return RespDTO.onError("未接收到数据!");
            }
        } catch (Exception e) {
            aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息", "", JSON.toJSONString(list), "", e.getMessage());
            return RespDTO.onError(e.getMessage());
        }
    }

    /**
     * 运行质控-通过接口更新病历记录
     *
     * @param aMrContentVO
     * @return
     */
    public RespDTO<Map<String, Object>> executeMrRecordIng(AMrContentVO aMrContentVO) {
        String behospitalCode = null;
        try {
            if (aMrContentVO.getRecords() != null && aMrContentVO.getRecords().size() > 0) {
                AMrContentDTO aMrContentDTO = new AMrContentDTO();
                //循环验证数据有效性
                for (AMedicalRecordVO aMedicalRecordVO : aMrContentVO.getRecords()) {
                    if (behospitalCode == null) {
                        behospitalCode = aMedicalRecordVO.getBehospitalCode();
                    }
                    if (aMedicalRecordVO.getRecId() == null || "".equals(aMedicalRecordVO.getRecId())) {
                        return RespDTO.onError("请输入文书序号!");
                    } else if (aMedicalRecordVO.getHospitalId() == null) {
                        return RespDTO.onError("请输入医院编码!");
                    } else if (aMedicalRecordVO.getBehospitalCode() == null || "".equals(aMedicalRecordVO.getBehospitalCode())) {
                        return RespDTO.onError("请输入病人住院编码!");
                    } else if (aMedicalRecordVO.getRecTypeId() == null || "".equals(aMedicalRecordVO.getRecTypeId())) {
                        return RespDTO.onError("请输入病历类别编号!");
                    } else if (aMedicalRecordVO.getRecTitle() == null || "".equals(aMedicalRecordVO.getRecTitle())) {
                        return RespDTO.onError("请输入病历标题!");
                    } else if (aMedicalRecordVO.getContents() == null || aMedicalRecordVO.getContents().size() == 0) {
                        return RespDTO.onError("请输入文书详情!");
                    }
                }
                aMedAbnormalInfoFacade.saveAbnormalInfo(behospitalCode+"mrRecord", behospitalCode, JSON.toJSONString(aMrContentVO), "", "!");
                //更新文书信息
                executeMrRecord(aMrContentVO.getRecords());
                aMrContentVO.getRecords().stream().forEach(s -> {
                    if (StringUtil.isNotEmpty(aMrContentVO.getTranscode())) {
                        String sql = "SELECT CONTENTS FROM AI_V_SENDMRRECORDING WHERE RECID = '" + s.getRecId() + "' AND BEHOSPITALCODE = '" + s.getBehospitalCode() + "'";
                        s.getContents().get(0).setXmlText(tzDBConn.getRecordXml(sql));
                    }

                    aMedicalRecordContentFacade.executeMrRecordContent(s.getContents());
                    /*查看试图日间病例标识*/
                    String sql = "SELECT * FROM AI_V_SENDPATIENTINFO t WHERE t.BEHOSPITALCODE='" + s.getBehospitalCode() + "'";
                    List<BehospitalInfo> behospitalInfos = tzDBConn.getBehospitalInfo(sql);
                    BehospitalInfo hospitalInfo = null;
                    if (behospitalInfos.size() > 0) {
                        hospitalInfo = behospitalInfos.get(0);
                    }
                    aMedAbnormalInfoFacade.saveAbnormalInfo(s.getBehospitalCode()+"mrRecord", s.getBehospitalCode(), hospitalInfo.getIsDaytime(), "", "!");
                    //更新日间病例标识 isDaytime
                    if(hospitalInfo.getIsDaytime().equals("1")){
                        UpdateWrapper<BehospitalInfo> wrapper = new UpdateWrapper<>();
                        wrapper.eq("behospital_code",s.getBehospitalCode())
                                .eq("is_deleted","N")
                                .set("is_daytime",1);
                        behospitalInfoService.update(wrapper);
                    }

                    BehospitalInfo behospitalInfo =behospitalInfoFacade.getOne(new QueryWrapper<BehospitalInfo>().eq("behospital_code", s.getBehospitalCode()));
                    UpdateWrapper<BehospitalInfo> wrapper = new UpdateWrapper<>();
                    //使用试图日间标识 判断是否是日间病例
                    if (hospitalInfo.getIsDaytime().equals("1")) {

                        if (behospitalInfo.getSex().equals(SexEnum.NUM_MALE.getName())) {
                            QcType byId = qcTypeFacade.getById("129");
                            wrapper.eq("behospital_code",s.getBehospitalCode())
                                    .eq("is_deleted","N")
                                    .set("qc_type_id",byId.getId());

                        }else{
                            QcType byId = qcTypeFacade.getById("161");
                            wrapper.eq("behospital_code",s.getBehospitalCode())
                                    .eq("is_deleted","N")
                                    .set("qc_type_id",byId.getId());
                        }
                        behospitalInfoService.update(wrapper);

                    }else{
                        QcType qcType= qcTypeFacade.getOne(new QueryWrapper<QcType>()
                                .eq("beh_dept_id", behospitalInfo.getBehDeptId())
                                .eq("default_module",0)
                                .eq("sex",behospitalInfo.getSex())
                                .eq("hospital_id", behospitalInfo.getHospitalId())
                                .eq("is_deleted", IsDeleteEnum.N));
                        //根据日间病例标志 查看质控类型 没有质控类型 则修改质控类型
//                        if (qcType==null) {
//
//                        }
                    }
});

                //评分后返回结构体
                if (aMrContentVO.getRecords().get(0).getRecTypeId().equals("BASY")) {
                    AHomePageIngVO aHomePageIngVO = new AHomePageIngVO();
                    aHomePageIngVO.setHomePages(getHomePageVo(aMrContentVO));
                    aHomePageIngVO.setDockModeType(aMrContentVO.getDockModeType());
                    return aHomePageFacade.executeHomePageIng(aHomePageIngVO);
                } else {
                    return mrIng(aMrContentVO);
                }
            } else {
                aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息", "", JSON.toJSONString(aMrContentVO), "", "未接收到数据!");
                return RespDTO.onError("未接收到数据!");
            }
        } catch (Exception e) {
            aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息", "", JSON.toJSONString(aMrContentVO), "", e.getMessage());
            return RespDTO.onError(e.getMessage());
        }
    }

    /**
     * 评分后返回结构体
     *
     * @param aMrContentVO
     * @return
     */
    private RespDTO<Map<String, Object>> mrIng(AMrContentVO aMrContentVO) {
        try {
            String behospitalCode = aMrContentVO.getRecords().get(0).getBehospitalCode();
            Long hospitalId = aMrContentVO.getRecords().get(0).getHospitalId();
            MedicalRecord medicalRecord = new MedicalRecord();
            BeanUtil.copyProperties(aMrContentVO.getRecords().get(0), medicalRecord);
            Long modeId = initModeId(medicalRecord);
            if (aMrContentVO.getDockModeType().equals("0")) {
                Map<String, Object> map = new HashMap<String, Object>();
                List<AMedicalRecordDTO> medicalRecordDTOList = BeanUtil.listCopyTo(aMrContentVO.getRecords(), AMedicalRecordDTO.class);
                map.put("records", medicalRecordDTOList);
                //aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息",JSON.toJSONString(aMrContentVO),JSON.toJSONString(RespDTO.onSuc(map)),"操作正常!");
                return RespDTO.onSuc("保存成功");
            } else if (aMrContentVO.getDockModeType().equals("1")) {
                if (modeId == null || modeId == 0) {
                    return RespDTO.onSuc("无对应的文书类型");
                }
                //页面模式
                String url = readProperties.getProcessQcUrl() + "?behospitalCode=" + behospitalCode + "&hospitalId=" + hospitalId + "&modeId=" + modeId;
                Map<String, Object> map = new HashMap<String, Object>();
                map.put("url", url);
                //aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息",JSON.toJSONString(aMrContentVO),JSON.toJSONString(RespDTO.onSuc(map)),"操作正常!");
                return RespDTO.onSuc(map);
            } else if (aMrContentVO.getDockModeType().equals("2")) {
                AnalyzeRunVO analyzeRunVO = new AnalyzeRunVO();
                analyzeRunVO.setBehospitalCode(behospitalCode);
                analyzeRunVO.setHospitalId(hospitalId);
                analyzeRunVO.setModeId(modeId);
                AnalyzeRunDTO analyzeRunDTO = behospitalInfoFacade.analyzeRun(analyzeRunVO);
                Map<String, Object> map = new HashMap<String, Object>();
                if (analyzeRunDTO.getMsgDTOList().size() > 0) {
                    map.put("analyze", analyzeRunDTO.getMsgDTOList());
                }
                //aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息",JSON.toJSONString(aMrContentVO),JSON.toJSONString(RespDTO.onSuc(map)),"操作正常!");
                //接口引擎模式
                return RespDTO.onSuc(map);
            } else {
                if (modeId == null || modeId == 0) {
                    return RespDTO.onSuc("无对应的文书类型");
                }
                //页面模式
                String url = readProperties.getProcessQcUrl() + "?behospitalCode=" + behospitalCode + "&hospitalId=" + hospitalId + "&modeId=" + modeId;
                Map<String, Object> map = new HashMap<String, Object>();
                AnalyzeRunVO analyzeRunVO = new AnalyzeRunVO();
                analyzeRunVO.setBehospitalCode(behospitalCode);
                analyzeRunVO.setHospitalId(hospitalId);
                analyzeRunVO.setModeId(modeId);
                AnalyzeRunDTO analyzeRunDTO = behospitalInfoFacade.analyzeRun(analyzeRunVO);

                if (analyzeRunDTO.getMsgDTOList().size() > 0) {
                    map.put("url", url);
                    map.put("analyze", analyzeRunDTO.getMsgDTOList());
                }
                //aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息",JSON.toJSONString(aMrContentVO),JSON.toJSONString(RespDTO.onSuc(map)),"操作正常!");
                return RespDTO.onSuc(map);
            }
        } catch (Exception e) {
            aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息", "", JSON.toJSONString(aMrContentVO), "", e.getMessage());
            if (e.getMessage().contains("该病历无关联的质控条目")) {
                return RespDTO.onSuc(e.getMessage());
            } else {
                return RespDTO.onError(e.getMessage());
            }

        }

    }

    public List<AHomePageVO> getHomePageVo(AMrContentVO aMrContentVO) {
        String behospitalCode = aMrContentVO.getRecords().get(0).getBehospitalCode();
        Long hospitalId = aMrContentVO.getRecords().get(0).getHospitalId();
        String homePageXml = aMrContentVO.getRecords().get(0).getContents().get(0).getXmlText();
        Map<String, Object> ret = YiWuFirstPageRecordXmlUtil.process(homePageXml);
        JSONObject paramsObj = new JSONObject(ret);
        List<AHomePageVO> aHomePageVOList = Lists.newLinkedList();
        AHomePageVO aHomePageVO = new AHomePageVO();
        aHomePageVO.setHomePageId(behospitalCode);
        aHomePageVO.setHospitalId(hospitalId);
        aHomePageVO.setBehospitalCode(behospitalCode);
        //aHomePageVO.setHospitalCode();
        aHomePageVO.setRescueNum(paramsObj.getString("抢救次数"));
        aHomePageVO.setRescueSuccessNum(paramsObj.getString("抢救成功次数"));
        aHomePageVO.setHospitalName(paramsObj.getString("医院代码"));
        //aHomePageVO.setOrgCode();
        aHomePageVO.setPayType(paramsObj.getString("医疗付费方式"));
        aHomePageVO.setHealthCard(paramsObj.getString("居民健康卡号"));
        aHomePageVO.setBehospitalNum(paramsObj.getString("住院次数"));
        aHomePageVO.setFileCode(paramsObj.getString("病案号"));
        aHomePageVO.setName(paramsObj.getString("姓名"));
        aHomePageVO.setSex(paramsObj.getString("性别"));
        if (StringUtil.isNotEmpty(paramsObj.getString("出生日期").replaceAll("[\u4e00-\u9fa5]", "").trim())) {
            aHomePageVO.setBirthday(paramsObj.getString("出生日期").replaceAll("[\u4e00-\u9fa5]", "-"));
        }
        String ageMap = "";
        if(StringUtil.isNotEmpty(paramsObj.getString("年龄新")) && Pattern.compile(".*\\d+.*").matcher(paramsObj.getString("年龄新")).matches()){
            ageMap = paramsObj.getString("年龄新");
        }
        if(StringUtil.isNotEmpty(paramsObj.getString("新生儿年龄")) && Pattern.compile(".*\\d+.*").matcher(paramsObj.getString("新生儿年龄")).matches()){
            ageMap = paramsObj.getString("新生儿年龄");
        }
        if(StringUtil.isNotEmpty(paramsObj.getString("婴儿年龄")) && Pattern.compile(".*\\d+.*").matcher(paramsObj.getString("婴儿年龄")).matches()){
            ageMap = paramsObj.getString("婴儿年龄");
        }
        if(!"".equals(ageMap) && Pattern.compile("^[-\\+]?[\\d]*$").matcher(ageMap.trim().replaceAll("[\u4e00-\u9fa5+-~:、，,./`]", "")).matches()){
            String tempAgeMap = ageMap.replaceAll("[\u4e00-\u9fa5]", "");
            aHomePageVO.setAge(tempAgeMap);
            if(ageMap.contains("天")){
                aHomePageVO.setAgeUnit("天");
                aHomePageVO.setNewbornDay(tempAgeMap);
            }else if(ageMap.contains("月")){
                aHomePageVO.setAgeUnit("月");
                aHomePageVO.setNewbornMonth(tempAgeMap);
            }else if(ageMap.contains("岁")){
                aHomePageVO.setAgeUnit("岁");
            }else if(ageMap.contains("分")){
                aHomePageVO.setAgeUnit("分钟");
            }else if(ageMap.contains("时")){
                aHomePageVO.setAgeUnit("小时");
            }else if(ageMap.contains("周")){
                aHomePageVO.setAgeUnit("周");
            }else {
                aHomePageVO.setAgeUnit("月");
            }
            if(ageMap.contains("时")&& ageMap.contains("分")){
                aHomePageVO.setAge(ageMap);
                aHomePageVO.setAgeUnit("");
            }
        }
        if(StringUtil.isNotEmpty(paramsObj.getString("新生儿出生月数"))){
            aHomePageVO.setNewbornMonth(paramsObj.getString("新生儿出生月数"));
        }
        if(StringUtil.isNotEmpty(paramsObj.getString("新生儿出生天数"))){
            aHomePageVO.setNewbornDay(paramsObj.getString("新生儿出生天数"));
        }
        aHomePageVO.setNationality(coverValue(paramsObj.getString("国籍"),"GJ"));
        aHomePageVO.setNewbornWeight(paramsObj.getString("新生儿出生体重"));
        aHomePageVO.setNewbornBehospitalWeight(paramsObj.getString("新生儿入院体重"));
        String[] provinceList = paramsObj.getString("省").split(" ");
        String[] cityList = paramsObj.getString("市").split(" ");
        String[] areaList = paramsObj.getString("县").split(" ");
        if (provinceList.length > 0) {
            if (provinceList[0].length() > 1) {
                aHomePageVO.setBornAddress(CITY_MAP.get(provinceList[0]) == null ? "" : CITY_MAP.get(provinceList[0]));
            }
            if (provinceList[1].length() > 1) {
                aHomePageVO.setResidenceAddress(CITY_MAP.get(provinceList[1]) == null ? "" : CITY_MAP.get(provinceList[1]));
            }
        }
        if (cityList.length > 0) {
            if (cityList[0].length() > 1) {
                aHomePageVO.setBornAddress(aHomePageVO.getBornAddress() + (CITY_MAP.get(cityList[0]) == null ? "" : CITY_MAP.get(cityList[0])));
            }
            if (cityList[1].length() > 1) {
                aHomePageVO.setResidenceAddress(aHomePageVO.getResidenceAddress() + (CITY_MAP.get(cityList[1]) == null ? "" : CITY_MAP.get(cityList[1])));
            }
        }
        if (areaList.length > 0) {
            if (areaList[0].length() > 1) {
                aHomePageVO.setBornAddress(aHomePageVO.getBornAddress() + (CITY_MAP.get(areaList[0]) == null ? "" : CITY_MAP.get(areaList[0])));
            }
            if (areaList[1].length() > 1) {
                aHomePageVO.setResidenceAddress(aHomePageVO.getResidenceAddress() + (CITY_MAP.get(areaList[1]) == null ? "" : CITY_MAP.get(areaList[1])));
            }
        }
        aHomePageVO.setResidenceAddress(aHomePageVO.getResidenceAddress() + paramsObj.getString("户口地址其它"));
        aHomePageVO.setBornPlace(CITY_MAP.get(paramsObj.getString("籍贯_省")) + CITY_MAP.get(paramsObj.getString("籍贯_市")));
        aHomePageVO.setNation(coverValue(paramsObj.getString("民族"),"MZ"));
        aHomePageVO.setIdentityCardNo(paramsObj.getString("身份证号"));
        aHomePageVO.setJobType(coverValue(paramsObj.getString("职业"),"ZY"));
        aHomePageVO.setMarriage(paramsObj.getString("婚姻"));
        aHomePageVO.setCurAddress(CITY_MAP.get(paramsObj.getString("现住址_省")) + CITY_MAP.get(paramsObj.getString("现住址_市")) + CITY_MAP.get(paramsObj.getString("现住址_县")) + paramsObj.getString("现住址其它"));
        aHomePageVO.setCurPhone(paramsObj.getString("现住址电话"));
        aHomePageVO.setCurPostCode(paramsObj.getString("现住址邮编"));
        aHomePageVO.setResidencePostCode(paramsObj.getString("户口地址邮编"));
        aHomePageVO.setWorkAddress(paramsObj.getString("工作单位"));
        aHomePageVO.setWorkPhone(paramsObj.getString("工作单位电话"));
        aHomePageVO.setWorkPostCode(paramsObj.getString("工作单位邮编"));
        aHomePageVO.setContactName(paramsObj.getString("联系人姓名"));
        aHomePageVO.setContactRelation(coverValue(paramsObj.getString("联系人关系"),"GX"));
        aHomePageVO.setContactAddress(paramsObj.getString("联系人地址"));
        aHomePageVO.setContactPhone(paramsObj.getString("联系人电话"));
        if (StringUtil.isNotBlank(paramsObj.getString("入院途径"))) {
            aHomePageVO.setBehospitalWay(BehospitalWayXmlEnum.getName(paramsObj.getString("入院途径").split(" ")[0]));
        }
        if (YWDateUtils.isDate(paramsObj.getString("入院时间"), "yyyy年MM月dd日 HH时mm分") || YWDateUtils.isDate(paramsObj.getString("入院时间"), "yyyy-MM-dd HH:mm:ss")) {
            aHomePageVO.setBehospitalDate(DateUtil.format(YWDateUtils.parseDateTime(paramsObj.getString("入院时间")), DateUtil.DATE_TIME_FORMAT));
        }
        aHomePageVO.setBehospitalDept(coverValue(paramsObj.getString("入院科别"),"KS"));
        aHomePageVO.setBehospitalWard(paramsObj.getString("入院病房"));
        aHomePageVO.setChangeDept(paramsObj.getString("转科科别"));
        if (YWDateUtils.isDate(paramsObj.getString("出院时间"), "yyyy-MM-dd HH:mm:ss") || YWDateUtils.isDate(paramsObj.getString("出院时间"), "yyyy年MM月dd日 HH时mm分")) {
            aHomePageVO.setLeaveHospitalDate(DateUtil.format(YWDateUtils.parseDateTime(paramsObj.getString("出院时间")), DateUtil.DATE_TIME_FORMAT));
        }
        aHomePageVO.setLeaveHospitalDept(paramsObj.getString("出院科别"));
        aHomePageVO.setLeaveHospitalWard(paramsObj.getString("出院病房"));
        aHomePageVO.setBehospitalDayNum(paramsObj.getString("实际住院天数"));
        aHomePageVO.setOutpatientEmrDiagnose(paramsObj.getString("门急诊诊断"));
        aHomePageVO.setOutpatientEmrDiagnoseCode(paramsObj.getString("门诊诊断编码"));
        aHomePageVO.setPoisonFactor(paramsObj.getString("损伤中毒因素"));
        aHomePageVO.setPoisonFactorCode(paramsObj.getString("损伤中毒因素编码"));
        aHomePageVO.setPathologyDiagnose(paramsObj.getString("病理诊断"));
        aHomePageVO.setPathologyDiagnoseCode(paramsObj.getString("病理诊断编码"));
        aHomePageVO.setIsMedAllergy(paramsObj.getString("药物过敏"));
        aHomePageVO.setMedAllergyName(paramsObj.getString("过敏药物"));
        aHomePageVO.setAutopsy(paramsObj.getString("死亡患者尸检"));
        aHomePageVO.setBloodType(paramsObj.getString("血型"));
        aHomePageVO.setRh(paramsObj.getString("Rh"));
        aHomePageVO.setDeptDirector(coverValue(paramsObj.getString("科主任"),"ZG"));
        aHomePageVO.setDirectorDoctor(coverValue(paramsObj.getString("主任医师"),"ZG"));
        aHomePageVO.setAttendingDoctor(coverValue(paramsObj.getString("主治医师"),"ZG"));
        aHomePageVO.setBehospitalDoctor(coverValue(paramsObj.getString("住院医师"),"ZG"));
        aHomePageVO.setResponseNurse(coverValue(paramsObj.getString("责任护士"),"ZG"));
        aHomePageVO.setStudyDoctor(coverValue(paramsObj.getString("进修医师"),"ZG"));
        aHomePageVO.setPracticeDoctor(coverValue(paramsObj.getString("实习医师"),"ZG"));
        aHomePageVO.setEncodeMan(coverValue(paramsObj.getString("编码员"),"ZG"));
        aHomePageVO.setHomePageQuality(paramsObj.getString("病案质量"));
        aHomePageVO.setQcDoctor(coverValue(paramsObj.getString("质控医师"),"ZG"));
        aHomePageVO.setQcNurse(coverValue(paramsObj.getString("质控护士"),"ZG"));
        if (YWDateUtils.isDate(paramsObj.getString("质控日期"), "yyyy-MM-dd HH:mm:ss")) {
            aHomePageVO.setQcDate(DateUtil.format(YWDateUtils.parseDateTime(paramsObj.getString("质控日期")), DateUtil.DATE_TIME_FORMAT));
        } else if(YWDateUtils.isDate(paramsObj.getString("质控日期"), "yyyy年MM月dd日")){
            aHomePageVO.setQcDate(paramsObj.getString("质控日期").replaceAll("[\u4e00-\u9fa5]", "-"));
        }
        aHomePageVO.setLeaveHospitalType(paramsObj.getString("离院方式"));
        //aHomePageVO.setLeaveHospitalType(LeaveHospitalTypeEnum.getName(paramsObj.getString("离院方式")));
        aHomePageVO.setAcceptOrgCode(paramsObj.getString("接收机构名称"));
        aHomePageVO.setAgainBehospitalPlan(paramsObj.getString("三十一天内再住院计划"));
        aHomePageVO.setAgainBehospitalGoal(paramsObj.getString("再住院目的"));
        aHomePageVO.setTbiBeforeDay(paramsObj.getString("颅脑损伤患者昏迷前天数"));
        aHomePageVO.setTbiBeforeHour(paramsObj.getString("颅脑损伤患者昏迷前小时"));
        aHomePageVO.setTbiBeforeMinute(paramsObj.getString("颅脑损伤患者昏迷前分钟"));
        aHomePageVO.setTbiAfterDay(paramsObj.getString("颅脑损伤患者昏迷后天数"));
        aHomePageVO.setTbiAfterHour(paramsObj.getString("颅脑损伤患者昏迷后小时"));
        aHomePageVO.setTbiAfterMinute(paramsObj.getString("颅脑损伤患者昏迷后分钟"));
        aHomePageVO.setTotalFee(paramsObj.getString("总费用"));
        aHomePageVO.setOwnFee(paramsObj.getString("自付金额"));
        aHomePageVO.setGeneralFee(paramsObj.getString("一般医疗服务费"));
        aHomePageVO.setServiceFee(paramsObj.getString("一般治疗服务费"));
        aHomePageVO.setNurseFee(paramsObj.getString("护理费"));
        aHomePageVO.setOtherFee(paramsObj.getString("其他费用"));
        aHomePageVO.setPathologyFee(paramsObj.getString("病理诊断费"));
        aHomePageVO.setLabFee(paramsObj.getString("实验室诊断费"));
        aHomePageVO.setPacsFee(paramsObj.getString("影像学诊断费"));
        aHomePageVO.setClinicDiagnoseFee(paramsObj.getString("临床诊断项目费"));
        aHomePageVO.setNotOperationFee(paramsObj.getString("非手术治疗项目费"));
        aHomePageVO.setClinicPhysicFee(paramsObj.getString("临床物理治疗费"));
        aHomePageVO.setOperationTreatFee(paramsObj.getString("手术治疗费"));
        aHomePageVO.setAnaesthesiaFee(paramsObj.getString("麻醉费"));
        aHomePageVO.setHealthTypeFee(paramsObj.getString("康复类"));
        aHomePageVO.setChnTreatFee(paramsObj.getString("中医治疗费"));
        aHomePageVO.setWesternMedFee(paramsObj.getString("西药费"));
        aHomePageVO.setAntibiosisFee(paramsObj.getString("抗菌药物费用"));
        aHomePageVO.setChnMedFee(paramsObj.getString("中成药费"));
        aHomePageVO.setChnHerbFee(paramsObj.getString("中草药费"));
        aHomePageVO.setBloodFee(paramsObj.getString("血费"));
        aHomePageVO.setAlbumenFee(paramsObj.getString("白蛋白类制品费"));
        aHomePageVO.setGlobulinFee(paramsObj.getString("球蛋白类制品费"));
        aHomePageVO.setBloodFactorFee(paramsObj.getString("凝血因子类制品费"));
        aHomePageVO.setCellFactorFee(paramsObj.getString("细胞因子类制品费"));
        aHomePageVO.setCheckMaterialFee(paramsObj.getString("检查用一次性医用材料费"));
        aHomePageVO.setTreatMaterialFee(paramsObj.getString("治疗用一次性医用材料费"));
        aHomePageVO.setOperationMaterialFee(paramsObj.getString("手术用一次性医用材料费"));
        aHomePageVO.setOtherTypeFee(paramsObj.getString("其他类其他费"));
        if(StringUtil.isNotEmpty(paramsObj.getString("单病种管理"))){
            aHomePageVO.setSingleDiagManage(paramsObj.getString("单病种管理").trim());
        }
        if(StringUtil.isNotEmpty(paramsObj.getString("单病种管理_"))){
            aHomePageVO.setSingleDiagManage(paramsObj.getString("单病种管理_").trim());
        }
        if(StringUtil.isNotEmpty(paramsObj.getString("临床路径管理"))){
            aHomePageVO.setClinicPathwayManage(paramsObj.getString("临床路径管理").trim());
        }
        if(StringUtil.isNotEmpty(paramsObj.getString("临床路径管理_"))){
            aHomePageVO.setClinicPathwayManage(paramsObj.getString("临床路径管理_").trim());
        }
        aHomePageVO.setIsOutpatientBehospital(paramsObj.getString("门诊与住院"));
        aHomePageVO.setIsLeaveBehospital(paramsObj.getString("入院与出院"));
        aHomePageVO.setIsOperationBeforeAfter(paramsObj.getString("术前与术后"));
        aHomePageVO.setIsClinicPathology(paramsObj.getString("临床与病理"));
        aHomePageVO.setIsRadiatePathology(paramsObj.getString("放射与病理"));
        if(StringUtil.isNotEmpty(paramsObj.getString("转归情况"))){
            aHomePageVO.setReturnToType(paramsObj.getString("转归情况").trim());
        }
        if(StringUtil.isNotEmpty(paramsObj.getString("转归情况_"))){
            aHomePageVO.setReturnToType(paramsObj.getString("转归情况_").trim());
        }
        //定位id暂时存字段中
        String idsJson = JSONObject.toJSONString(ret.get("IDs"));
        aHomePageVO.setHospitalCode(idsJson);
        List<Object> operationList = paramsObj.getJSONArray("手术信息");
        String ssqkSql = "SELECT * FROM AI_V_SENDHOMEPAGEING_SSQK t where t.homepageid = '" + behospitalCode + "'";
        String cyzdSql = "SELECT * FROM AI_V_SENDHOMEPAGEING_CYZD t where t.homepageid = '" + behospitalCode + "'";
        aHomePageVO.setOperations(tzDBConn.getHomePageOperation(ssqkSql));
        aHomePageVO.setLeaveDiags(tzDBConn.getHomePageDiagnose(cyzdSql));
        aHomePageVOList.add(aHomePageVO);
        return aHomePageVOList;
    }


    public void execute(List<MedicalRecord> medicalRecordList) {
        try {
            List<MedicalRecord> addE = Lists.newLinkedList();
            List<MedicalRecord> updateE = Lists.newLinkedList();
            List<BehospitalInfo> behospitalInfoList = Lists.newLinkedList();
            List<ModelHospital> modelHospitalList = Lists.newLinkedList();
            if (medicalRecordList != null && medicalRecordList.size() > 0) {
                medicalRecordList.stream().forEach(s -> {
                    //初始化mode_id
                    Long modeId = initModeId(s);
                    if (modeId == Long.valueOf("0")) {
                        //新增类型到监测表中
                        ModelHospital modelHospital=new ModelHospital();
                        modelHospital.setHospitalId(s.getHospitalId());
                        modelHospital.setHospitalModelName(s.getRecTitle());
                        modelHospital.setGmtCreate(new Date());
                        modelHospitalList.add(modelHospital);
                    } else if (modeId == Long.valueOf("1")) {
                        BehospitalInfo behospitalInfo = behospitalInfoFacade.getOne(new QueryWrapper<BehospitalInfo>()
                                .eq("behospital_code", s.getBehospitalCode())
                                .eq("hospital_id", s.getHospitalId())
                                .eq("is_deleted", IsDeleteEnum.N), false);
                        if (behospitalInfo != null) {
                            //如果病人住院信息存在，更新对应的qc_type_id
                            Long qcTypeId = initQcTypeId(s, behospitalInfo);
                            behospitalInfo.setQcTypeId(qcTypeId);
                            behospitalInfoList.add(behospitalInfo);
                        }
                    }
                    s.setModeId(modeId);
                    //新增或修改
                    QueryWrapper<MedicalRecord> queryWrapper = new QueryWrapper<>();
                    queryWrapper.eq("rec_id", s.getRecId());
                    queryWrapper.eq("hospital_id", s.getHospitalId());
                    queryWrapper.eq("behospital_code", s.getBehospitalCode());
                    MedicalRecord mRecord = this.getOne(queryWrapper);
                    if (mRecord != null) {
                        s.setGmtModified(new Date());
                        s.setIsDeleted(IsDeleteEnum.N.getKey());
                        medicalRecordService.update(s,queryWrapper);
                        //updateE.add(s);
                    } else {
                        s.setGmtCreate(new Date());
                        addE.add(s);
                    }
                });
            }
            if (addE.size() > 0) {
                medicalRecordService.saveBatch(addE);
            }
            /*if (updateE.size() > 0) {
                medicalRecordService.updateBatchByKey(updateE);
            }*/
            if (modelHospitalList.size() > 0) {
                modelHospitalService.saveBatch(modelHospitalList);
            }
            if (behospitalInfoList.size() > 0) {
                behospitalInfoFacade.updateBatchByKey(behospitalInfoList);
            }
        } catch (Exception e) {
            aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息", "", JSON.toJSONString(medicalRecordList), "", e.getMessage());
        }
    }

    /**
     * 初始化质控类型ID
     *
     * @param medicalRecord
     * @return
     */
    private Long initQcTypeId(MedicalRecord medicalRecord, BehospitalInfo behospitalInfo) {
        Long qcTypeId = Long.valueOf("0");
        String behDeptId = behospitalInfo.getBehDeptId();
        String recTypeId = medicalRecord.getRecTypeId();
        /*if (recTypeId.contains("RJBL") || recTypeId.contains("24XSCRYJL")) {
            if (behDeptId.equals("52425")) {
                *//**妇科(住)日间病历、24小时出入院记录的病历模板，映射妇科日间*//*
                behDeptId = "52883";
            } else if (behDeptId.equals("51944")) {
                *//**乳腺外科日间病历、24小时出入院记录的病历模板，映射乳腺外科日间日间*//*
                behDeptId = "52923";
            } else if (behDeptId.equals("52424") || behDeptId.equals("52643") || behDeptId.equals("51766")) {
                *//**儿科日间病历、24小时出入院记录的病历模板、小儿外科住、新生儿科，映射儿科日间*//*
                behDeptId = "52903";
            }else if(behDeptId.equals("52423") || behDeptId.equals("54065")){
                *//*外科(住院)、耳鼻喉科，映射日间病房*//*
                behDeptId="51923";
            }
        }*/

        log.info("behDeptId======="+behDeptId);
        //根据性别和科室查看质控类型
        QcType qcType= qcTypeFacade.getOne(new QueryWrapper<QcType>()
                .eq("beh_dept_id", behDeptId)
                .eq("default_module",0)
                .eq("sex",behospitalInfo.getSex())
                .eq("hospital_id", behospitalInfo.getHospitalId())
                .eq("is_deleted", IsDeleteEnum.N));
        //根据日间病例标志 查看质控类型 没有质控类型 则修改质控类型
        if (qcType==null) {
            if (behospitalInfo.getIsDaytime().equals("1")) {
                if (behospitalInfo.getSex().equals(SexEnum.NUM_MALE.getName())) {
                    QcType byId = qcTypeFacade.getById("129");
                    return byId.getId();
                }else{
                    QcType byId = qcTypeFacade.getById("161");
                    return byId.getId();
                }

            }
            //如果没有则查看默认模板
            QcType qcTypeD = qcTypeFacade.getOne(new QueryWrapper<QcType>()
                    .eq("default_module", 1)
                    .eq("hospital_id", behospitalInfo.getHospitalId())
                    .eq("is_deleted", IsDeleteEnum.N));
            qcTypeId = qcTypeD.getId();
        } else{
            qcTypeId = qcType.getId();
        }
        return qcTypeId;
    }

    /**
     * 初始化模型ID
     *
     * @param medicalRecord
     * @return
     */
    private Long initModeId(MedicalRecord medicalRecord) {
        Long modeId = Long.valueOf("0");
        try {
            QueryWrapper<ModelHospital> wrapper = new QueryWrapper<>();
            wrapper.eq("hospital_id", medicalRecord.getHospitalId());
            wrapper.eq("hospital_model_name", medicalRecord.getRecTitle());
            ModelHospital mode = modelHospitalFacade.getOne(wrapper, false);
            String recTitle = medicalRecord.getRecTitle();
            if (mode != null) {
                modeId = mode.getStandModelId();
            } else {
                modeId = Long.valueOf("0");
                ModelHospital modelHospital = new ModelHospital();
                modelHospital.setHospitalId(5L);
                modelHospital.setHospitalModelName(medicalRecord.getRecTitle());
                if (recTitle.contains("查房")) {
                    modeId = 4L;
                    modelHospital.setStandModelId(4L);
                    modelHospital.setStandModelName("查房记录");
                } else if (recTitle.contains("手术") && recTitle.contains("同意")) {
                    modeId = 16L;
                    modelHospital.setStandModelId(16L);
                    modelHospital.setStandModelName("知情同意书");
                } else if (recTitle.contains("有创") && recTitle.contains("知情同意书")) {
                    modeId = 59L;
                    modelHospital.setHospitalId(59L);
                    modelHospital.setHospitalModelName(recTitle);
                }
                modelHospitalFacade.save(modelHospital);
            }
            //aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息-初始化modeId",JSON.toJSONString(medicalRecord),modeId.toString(),"操作成功!");
            return modeId;
        } catch (Exception e) {
            aMedAbnormalInfoFacade.saveAbnormalInfo("文书信息-初始化modeId", medicalRecord.getRecId(), JSON.toJSONString(medicalRecord), "", e.getMessage());
            return modeId;
        }

    }

    public RespDTO deleteFlag(ADeleteFlagVO aDeleteFlagVO) {
        try {
            //验证数据是否存在
            if (StringUtil.isEmpty(aDeleteFlagVO.getRecId())) {
                return RespDTO.onError("请输入文书序号!");
            } else if (aDeleteFlagVO.getHospitalId() == null) {
                return RespDTO.onError("请输入医院编码!");
            } else if (StringUtil.isEmpty(aDeleteFlagVO.getBehospitalCode())) {
                return RespDTO.onError("请输入病人住院编码!");
            } else {
                UpdateWrapper<MedicalRecord> updateWrapper = new UpdateWrapper<>();
                updateWrapper.eq("rec_id", aDeleteFlagVO.getRecId())
                        .eq("hospital_id", aDeleteFlagVO.getHospitalId())
                        .eq("behospital_code", aDeleteFlagVO.getBehospitalCode())
                        .eq("is_deleted", IsDeleteEnum.N)
                        .set("is_deleted", IsDeleteEnum.Y)
                        .set("gmt_modified", DateUtil.now());
                Boolean flag = update(new MedicalRecord(), updateWrapper);
                if (flag) {
                    UpdateWrapper<MedicalRecordContent> updateWrapperContent = new UpdateWrapper<>();
                    updateWrapperContent.eq("rec_id", aDeleteFlagVO.getRecId())
                            .eq("hospital_id", aDeleteFlagVO.getHospitalId())
                            .eq("is_deleted", IsDeleteEnum.N)
                            .set("is_deleted", IsDeleteEnum.Y)
                            .set("gmt_modified", DateUtil.now());

                    Boolean flagContent = aMedicalRecordContentFacade.update(new MedicalRecordContent(), updateWrapperContent);
                }
                return RespDTO.onSuc(flag);
            }
        } catch (Exception e) {
            aMedAbnormalInfoFacade.saveAbnormalInfo("文书-删除", aDeleteFlagVO.getRecId(), JSON.toJSONString(aDeleteFlagVO), "", e.getMessage());
            return RespDTO.onError(e.getMessage());
        }
    }

    public String coverValue(String field, String type) {
        if(StringUtil.isNotEmpty(field) && !field.equals("-")){
            Pattern p = Pattern.compile("[\u4e00-\u9fa5]");
            Matcher m = p.matcher(field);
            if (type.equals("ZG")) {
                /**职工*/
                return m.find() ? field : tzDBConn.getDoctorName(field);
            } else if (type.equals("KS")) {
                /**科室*/
                return m.find() ? field : tzDBConn.getDeptName(field);
            } else if (type.equals("MZ")) {
                /**民族*/
                return m.find() ? field : FamousFamilyEnum.getName(field);
            } else if(type.equals("ZY")){
                /**职业*/
                return m.find() ? field : OccupationEnum.getName(field);
            } else if(type.equals("GJ")){
                /**国籍*/
                return m.find() ? field : NationalityEnum.getName(field);
            } else if (type.equals("GX")){
                /**联系人关系*/
                return m.find() ? field : RelationshipEnum.getName(field);
            }
        }
        return field;
    }

    public RespDTO getRecordToView(List<String> behospitalCodeList){
        behospitalCodeList.stream().forEach(code -> {
            List<BehospitalInfo> behospitalInfoList = tzDBConn.getBehospitalInfo("SELECT * FROM AI_V_SENDPATIENTINFO t WHERE t.BEHOSPITALCODE='" + code + "'");
            behospitalInfoList.stream().forEach(s -> {
                String viewName = "AI_V_SENDMRRECORDING";
                if(StringUtil.isNotBlank(s.getIsPlacefile()) && s.getIsPlacefile().equals("1")){
                    viewName += "GD";
                }
                execute(tzDBConn.getMedicalRecord("SELECT * FROM "+ viewName + " t WHERE t.BEHOSPITALCODE='" + code + "'"));
                aMedicalRecordContentFacade.execute(tzDBConn.getMedicalRecordContent("SELECT * FROM "+ viewName + " t WHERE t.BEHOSPITALCODE='" + code + "'"));
            });
        });
        return RespDTO.onSuc(behospitalCodeList);
    }

    public boolean hisDataDeal(HisDataDealVO hisDataDealVO) throws Exception {
        QueryWrapper<MedicalRecord> medicalRecordQe = new QueryWrapper<>();
        medicalRecordQe.eq("hospital_id", hisDataDealVO.getHospitalId());
        medicalRecordQe.eq("mode_id", hisDataDealVO.getModeId());
        medicalRecordQe.eq("is_deleted", IsDeleteEnum.N.getKey());
        medicalRecordQe.orderByDesc("rec_date","rec_id");
        if (hisDataDealVO.getRecIdList().size() > 0) {
            medicalRecordQe.in("rec_id", hisDataDealVO.getRecIdList());
        }
        List<MedicalRecord> medicalRecordList = medicalRecordService.list(medicalRecordQe);
        medicalRecordList.forEach(medicalRecord -> {
                    QueryWrapper<MedicalRecordContent> medicalRecordContentQe = new QueryWrapper<>();
                    medicalRecordContentQe.eq("hospital_id", hisDataDealVO.getHospitalId());
                    medicalRecordContentQe.eq("rec_id", medicalRecord.getRecId());
                    List<MedicalRecordContent> medicalRecordContentList = aMedicalRecordContentFacade.list(medicalRecordContentQe);

                    if (ListUtil.isEmpty(medicalRecordContentList)) {
                        return;
                    }

                    if (encryptFlag) {
                        try {
                            EncrypDES encrypDES = new EncrypDES();
                            for (MedicalRecordContent mrj : medicalRecordContentList) {
                                mrj.setXmlText(encrypDES.decryptor(mrj.getXmlText()));
                            }
                        } catch (Exception e) {
                            return;
                        }
                    }

                    List<AMedicalRecordContentVO> contents = BeanUtil.listCopyTo(medicalRecordContentList, AMedicalRecordContentVO.class);
                    AMedicalRecordVO aMedicalRecordVO = new AMedicalRecordVO();
                    BeanUtil.copyProperties(medicalRecord, aMedicalRecordVO);
                    aMedicalRecordVO.setContents(contents);
                    List<AMedicalRecordVO> records = Lists.newArrayList();
                    records.add(aMedicalRecordVO);
                    AMrContentVO aMrContentVO = new AMrContentVO();
                    aMrContentVO.setRecords(records);
                    splicingParam(aMrContentVO);
                }
        );
        return true;
    }


    /**
     * 特殊公共方法处理数据
     *
     * @param
     */
    public void specialDataWithKey(Boolean encryptFlag, List<RecordContentDTO> recordContentDTOS
    ) {

        if (encryptFlag) {
            try {
                EncrypDES encrypDES = new EncrypDES();
                for (RecordContentDTO mrj : recordContentDTOS) {
                    mrj.setXmlText(encrypDES.decryptor(mrj.getXmlText()));
                }
            } catch (Exception e) {
                log.error(e.getMessage(), e);
            }
        }

    }

    /**
     * 入参结构拼接-仅支持接口对接的方式
     *
     * @param aMrContentVO
     */
    public void splicingParam(AMrContentVO aMrContentVO) {

        try {
            QueryVo queryVo = new QueryVo();
            List<MedrecVo> medreclist = Lists.newArrayList();

            List<AColumnContentVO> content = Lists.newArrayList();
            aMrContentVO.getRecords().stream().forEach(s -> {
                queryVo.setHospitalId(s.getHospitalId().toString());
                queryVo.setCid(basHospitalInfoFacade.getHosCode(s.getHospitalId()));
                Long modeId ;
                if (null == s.getModeId()) {
                    MedicalRecord medicalRecord=new MedicalRecord();
                    BeanUtils.copyProperties(s,medicalRecord);
                    modeId = initModeId(medicalRecord);
                }else {
                    modeId = s.getModeId();
                }
                s.getContents().stream().forEach(item -> {
                    //拼接入参用于结构化解析
                    AColumnContentVO aColumnContentVO = new AColumnContentVO();
                    aColumnContentVO.setModeId(modeId);
                    aColumnContentVO.setStandModelName(ModeIdEnum.getName(Integer.parseInt(modeId.toString())));
                    aColumnContentVO.setRecId(s.getRecId());
                    aColumnContentVO.setRecTypeId(s.getRecTypeId());
                    aColumnContentVO.setRecTitle(s.getRecTitle());
                    aColumnContentVO.setXmlText(item.getXmlText());
                    aColumnContentVO.setBehospitalCode(s.getBehospitalCode());

                    content.add(aColumnContentVO);
                });
                Map<String, Object> map = new HashMap<String, Object>();
                List<Map<String, Object>> returnData = new ArrayList<>();
                String keyNname = ModeIdEnum.getName(Integer.parseInt(modeId.toString()));
                Map<String, List<Map<String, Object>>> returnMap = new HashMap<>();
                for (AColumnContentVO aColumnContentVO : content) {
                    try {
                        Map<String, Object> objectMap = MapUtil.objectToMap(aColumnContentVO);
                        returnData.add(objectMap);
                        returnMap.put(keyNname, returnData);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }

                map.put("content", returnData);
                MedrecVo medrecVo = new MedrecVo();
                medrecVo.setTitle(keyNname);
                medrecVo.setContent(map);
                medreclist.add(medrecVo);
            });
            queryVo.setMedrec(medreclist);

            columnFacade.analyseRec(queryVo);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            aMedAbnormalInfoFacade.saveAbnormalInfo("参数拼接", "", JSON.toJSONString(aMrContentVO), "", e.getMessage());
        }
    }
}